/*
 * Copyright (c) 2001-2004 Ant-Contrib project.  All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 package net.sf.antcontrib.inifile;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.io.Writer;
import java.util.*;


/****************************************************************************
 * Place class description here.
 *
 * @author <a href='mailto:mattinger@yahoo.com'>Matthew Inger</a>
 * @author		<additional author>
 *
 * @since
 *
 ****************************************************************************/


public class IniFile
{
    private List sections;
    private Map sectionMap;

    public IniFile()
    {
        super();
        this.sections = new ArrayList();
        this.sectionMap = new HashMap();
    }


    public List getSections()
    {
        return sections;
    }


    public IniSection getSection(String name)
    {
        return (IniSection)sectionMap.get(name);
    }


    public void setSection(IniSection section)
    {
        IniSection sec = (IniSection)sectionMap.get(section.getName());
        if (sec != null)
        {
            int idx = sections.indexOf(sec);
            sections.set(idx, section);
        }
        else
        {
            sections.add(section);
        }

        sectionMap.put(section.getName(), section);
    }

    public void removeSection(String name)
    {
        IniSection sec = (IniSection)sectionMap.get(name);
        if (sec != null)
        {
            int idx = sections.indexOf(sec);
            sections.remove(idx);
            sectionMap.remove(name);
        }
    }

    public void write(Writer writer)
        throws IOException
    {
        Iterator it = sections.iterator();
        IniSection section = null;
        while (it.hasNext())
        {
            section = (IniSection)it.next();
            section.write(writer);
            writer.write(System.getProperty("line.separator"));
        }
    }

    public void read(Reader reader)
        throws IOException
    {
        BufferedReader br = new BufferedReader(reader);
        String line = null;

        IniSection currentSection = new IniSection("NONE");

        while ((line = br.readLine()) != null)
        {
            int pos = line.indexOf('#');
            if (pos != -1)
                line = line.substring(0,pos);
            line = line.trim();
            if (line.length() > 0)
            {
                if(line.startsWith("[") && line.endsWith("]"))
                {
                    String secName = line.substring(1, line.length()-1);
                    currentSection = new IniSection(secName);
                    setSection(currentSection);
                }
                else
                {
                    String name = line;
                    String value = "";
                    pos = line.indexOf("=");
                    if (pos != -1)
                    {
                        name = line.substring(0,pos);
                        value = line.substring(pos+1);
                    }

                    currentSection.setProperty(new IniProperty(name,value));
                }
            }


        }
    }
}
