/*
 * Copyright (c) 2001-2004 Ant-Contrib project.  All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 package net.sf.antcontrib.inifile;

import java.io.IOException;
import java.io.Writer;
import java.util.*;


/****************************************************************************
 * Place class description here.
 *
 * @author <a href='mailto:mattinger@yahoo.com'>Matthew Inger</a>
 * @author		<additional author>
 *
 * @since
 *
 ****************************************************************************/


public class IniSection
        implements IniPart
{
    private String name;
    private List properties;
    private Map propertyMap;

    public IniSection()
    {
        super();
        this.propertyMap = new HashMap();
        this.properties = new ArrayList();
    }


    public IniSection(String name)
    {
        this();
        this.name = name;
    }


    public List getProperties()
    {
        return properties;
    }


    public String getName()
    {
        return name;
    }


    public void setName(String name)
    {
        this.name = name;
    }


    public void write(Writer writer)
        throws IOException
    {
        writer.write("[" + name + "]");
        writer.write(System.getProperty("line.separator"));
        Iterator it = properties.iterator();
        IniProperty prop = null;
        while (it.hasNext())
        {
            prop = (IniProperty)it.next();
            prop.write(writer);
            writer.write(System.getProperty("line.separator"));
        }
    }

    public IniProperty getProperty(String name)
    {
        return (IniProperty)propertyMap.get(name);
    }

    public void setProperty(IniProperty property)
    {
        IniProperty prop = (IniProperty)propertyMap.get(property.getName());
        if (prop != null)
        {
            int idx = properties.indexOf(prop);
            properties.set(idx, property);
        }
        else
        {
            properties.add(property);
        }

        propertyMap.put(property.getName(), property);
    }

    public void removeProperty(String name)
    {
        IniProperty prop = (IniProperty)propertyMap.get(name);
        if (prop != null)
        {
            int idx = properties.indexOf(prop);
            properties.remove(idx);
            propertyMap.remove(name);
        }
    }
}
